==> haskell-vty-crossplatform-0.4.0.0-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-LAfLC9KKytrGnQY5d79O2U
key:                  vty-crossplatform-0.4.0.0-LAfLC9KKytrGnQY5d79O2U
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  faddbbf3f0cff4fbe8912c2d93a80bf4
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-LAfLC9KKytrGnQY5d79O2U
depends:
    base-4.17.2.1 vty-6.1-JSaLsmvL0EzAEn94TGUVYo
    vty-unix-0.2.0.0-36zlul0zIT83FEzMx51anK

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-crossplatform-0.4.0.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-crossplatform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-crossplatform
version:              0.4.0.0
visibility:           public
id:                   vty-crossplatform-0.4.0.0-7MFVpaKKhCeJyIKhDTQ0KC
key:                  vty-crossplatform-0.4.0.0-7MFVpaKKhCeJyIKhDTQ0KC
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Cross-platform support for Vty
description:
    This package provides a generic interface for multiple
    Vty platforms in one package so you don'\''t have to
    conditionally depend on them in your cabal file.

category:             Graphics
abi:                  fe2cd271a0c707338f859c41ead607e8
exposed:              True
exposed-modules:
    Graphics.Vty.CrossPlatform Graphics.Vty.CrossPlatform.Testing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-crossplatform-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-crossplatform
hs-libraries:         HSvty-crossplatform-0.4.0.0-7MFVpaKKhCeJyIKhDTQ0KC
depends:
    base-4.17.2.1 vty-6.1-1PriwWlVbKPEcQdcNjlMse
    vty-unix-0.2.0.0-B4uUVjayBKrLgCcmkEGqYs

haddock-interfaces:
    /usr/share/doc/haskell-vty-crossplatform/html/vty-crossplatform.haddock

haddock-html:         /usr/share/doc/haskell-vty-crossplatform/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
